Struct iota_wallet::secret::types::InputSigningData
[−]pub struct InputSigningData {
pub output: Output,
pub output_metadata: OutputMetadata,
pub chain: Option<Chain>,
pub bech32_address: String,
}Expand description
Data for transaction inputs for signing and ordering of unlock blocks
Fields
output: OutputThe output
output_metadata: OutputMetadataThe output metadata
chain: Option<Chain>The chain derived from seed, only for ed25519 addresses
bech32_address: StringThe bech32 encoded address, required because of alias outputs where we have multiple possible unlock conditions, because we otherwise don’t know which one we need
Implementations
impl InputSigningData
impl InputSigningData